#messages-controls .messages-all-button {
    display: none;
}


#debug-imessage,
#debug,
.debug {
    display:none;
}
#message-stream ul.latest-messages {
    margin: 0 0 0 0;
    padding: 0;
        list-style:none;
}

#message-stream ul.latest-messages li {

    background-color: #F6F6F6;
    border: 1px solid #CCCCCC;
    border-radius: 0.3em 0.3em 0.3em 0.3em;
    font-size: 11px;
    margin: 10px 0;
    overflow: hidden;
    padding: 6px;
}
#message-stream ul li.send {

}

#message-stream .latest-message-wrapper {
    float:left;
    width:100%;
}

#message-stream .latest-messages .read-ok {
       border:1px solid #789F09;
           background-color:#E9FDD7 !important;
}

/*#message-stream .message-read-button .read-ok,
#message-stream .message-read-button:hover {
    background: transparent url("++resource++ityou.imessage.portlets.resources/read-icon-active.png") no-repeat left center ;
    padding:4px;
    float:right;
       opacity:1;

}*/

#message-stream .message-portrait {
    float: left;
    height: 48px !important;
    width: 48px !important;
    margin: 0 5px 0 0 !important;
    padding: 0px;
    position: relative;
}

#message-stream .very-small-personal-portrait {
    width: 32px;
}

#message-stream .message-portrait img {
    position: absolute;
    top:0px;
    left:0px;
    clip: rect(0px 48px 48px 0px);
}
#message-stream .message-portrait img.very-small-personal-portrait {
    position: absolute;
    top:0px;
    left:0px;
    clip: rect(0px 32px 32px 0px);
}
#message-stream .small-personal-portrait {
}
#message-stream .very-small-personal-portrait {
}


#message-stream .message-text {
    margin-left:50px;
    padding:0;
}



#message-stream ul.dialog {
    margin-left: 0;
    margin-right: 0;
}
#message-stream ul.dialog li {
    border-bottom: 1px solid #e0e0e0;
    list-style: none;
    padding: 0.5em 0 0 0;
        width:100%;
}



.message-input-field textarea {
    padding: 0px;
       border:1px solid #ccc;
       border-radius:0.3em;
           background-color:#FFFFee;
           font-size:11px;
    width: 98%;
    min-height:6em;

}
.message-save-button {
    margin:5px 0 20px 0;
    float:right;
}
.messages-all-button {
    display:none;
}

#messages-controls {
    margin:4px 0 4px 0;
}

/*#message-stream .message-hide-button {
       background:  transparent url("++resource++ityou.imessage.images/eye-close.png") no-repeat center right ;
    padding:2px 6px 2px 6px;
    font-size:10px;
    color:#FFF;
    cursor:pointer;
    float:right;
       height:12px;
       width:17px;
       cursor:pointer;
}

#message-stream .message-delete-button {
       opacity:0.5;
       background: transparent url("++resource++ityou.imessage.portlets.resources/delete-icon.png") no-repeat center right ;
    padding:2px 6px 2px 6px;
    font-size:10px;
    color:#FFF;
    cursor:pointer;
    float:right;
       height:12px;
       width:17px;
       cursor:pointer;
}
#message-stream .message-read-button {
        background: transparent url("++resource++ityou.imessage.portlets.resources/read-icon.png") no-repeat center right ;
       opacity:0.5;
    padding:2px 6px 2px 6px;
    font-size:10px;
    color:#FFF;
    cursor:pointer;
    float:right;
       height:12px;
       width:17px;
       cursor:pointer;
}
#message-stream .message-delete-button:hover {
       opacity:1;
       background: transparent url("++resource++ityou.imessage.portlets.resources/delete-icon-active.png") no-repeat center right ;
}
#message-stream .message-read-button:hover {
        background: transparent url("++resource++ityou.imessage.portlets.resources/read-icon-active.png") no-repeat center right ;
       opacity:1;
}*/




#new-message-box .message-box-close-button {
    color:white;
    padding:0px 2px 0 2px;
    cursor:pointer;
    float:right;
    font-size:10px;
}
.message-all-button {
    background:none;
    color:#999;
}

.hash {
    display:none;
}

.jq-render {}
.jq-render-ex {}

#message-stream .message-wrapper {
    margin:0;
    padding:0;
    width:100%;
}

#message-stream ul.messages,
#message-stream ul.previous-messages  {
    margin:0;
    padding:0;
}
#message-stream .visualClear {
    font-size:1!important;
    height:1px !important;
    margin:0;
    padding:0;
}

#message-stream .timestamp {
    color: #999;
    font-size:10px;
    text-align:right;
    }
#message-stream .his-message {
    background-color:#eaeaea !important;
    }
#message-stream .new-message {
    background-color:#f6f6f6;
    }

#message-stream ul li.jq-more-messages {
    background-color:#f6f6f6;
}

#message-form {
    padding:10px;
    width:420px;
    background-color:#EEF4F9;
}
#message-form label {
    display:block;
    float:left;
    width:80px;
    font-color:#666;
    font-weight:normal;
}
#message-form #receiver-id {
    width:330px;
    display:block;
    float:left;
    border:1px solid #e0e0e0;
        padding:2px;
}
#message-form .new-message-input-field {
    float:left;
    width:330px;
    margin:0;
    font-size:11px;

}

.ajax-params.invisible {display:none}

fieldset #user-actions #send-message {
    display: block;
    padding:0.3em 0 0 24px !important;
    background: transparent url('++resource++ityou.imessage.images/email.png')  left 4pt no-repeat;
}

.template-messages .input_holder {
	position: relative;
} 



#receiver_list {
	max-height: 160px;
	overflow-y: scroll;
	overflow-x: hidden;
	-webkit-overflow-scrolling: touch;
	
	border-top: 1px solid #eaeaea;
    border-bottom: 1px solid #eaeaea;
    padding-top: 10px;
    padding-bottom: 10px;
}

#receiver_list ul {
	margin-left: 10px !important;
	margin-right: 10px !important;
	
	list-style: none;
}

#receiver_list li div.thumbnail {
	margin-bottom: 0;
}

#receiver_list li div.thumbnail .caption {
	margin-left: 50px;
}

#receiver_list li div.thumbnail .caption .close {
	position: absolute;
	top: 0;
	right: 20px;
}


form[name="message_receiver"] .input_holder {
    position: relative;
    margin: 10px 0;
}

form[name="message_receiver"] .input_holder input {
    width: 100%;
}

form[name="message_receiver"] .input_holder .usersearch {
    position: absolute;
    z-index: 10000;
    display: none;
    width: 100%;
    margin-top: -5px;
}

form[name="message_receiver"] .input_holder .usersearch ul.users {
    list-style: none !important;
    margin: 0 !important;
    padding: 0;
    background-color: #eaeaea;
    border: 1px solid #ccc;
    border-top: 0;
    width: 100%;
    max-height: 268px;
    overflow-y: scroll;
    -webkit-overflow-scrolling: touch;
}

form[name="message_receiver"] .input_holder .usersearch li/*:not(:first-child)*/ {
    border-top: 1px solid #ccc;
}

form[name="message_receiver"] .input_holder .usersearch li {
    margin-bottom: 0 !important;
    padding-bottom: 5px;
    padding-top: 5px;
}

form[name="message_receiver"] .input_holder .usersearch li a {
    display: block;
    position: relative;
    padding: 0 5px;
}

form[name="message_receiver"] .input_holder .usersearch li a h2 {
	margin: 0;
}

/* only for test purposes */
form[name="message_receiver"] .input_holder .usersearch li img {
	width: 48px;
	height: 48px;
}

form[name="message_receiver"] .input_holder .usersearch li a h2, form[name="message_receiver"] .input_holder .usersearch li a p {
    white-space: nowrap;
    margin-left: 55px;
    overflow: hidden;
    text-overflow: ellipsis;
    margin-bottom: 0;
}

form[name="message_receiver"] .input_holder .usersearch li a .button {
    position: absolute;
    right: 5px;
    top: 50%;
    font-size: 1.5em;
}

form[name="message_receiver"] .input_holder .usersearch li:hover,
form[name="message_receiver"] .input_holder .usersearch li.hover {
    background-color: #fff;
}


#message-textarea_toolbargroup {
    width: auto !important;
}

#message-stream li.latest-message.message-sent {
    width: 94%;
    float: right;
    background: #e0ffc1;
}

#message-stream li.latest-message.message-received {
    width: 94%;
}

#message-stream ul.latest-messages:after {
    clear: both;
    width: 0;
    height: 0;
    content: '';
    display: table;
}



#imessage-inbox .load-more-messages {
    cursor: pointer;
}

#imessage-inbox .unread {
    font-weight: bold;
}

#imessage-inbox tbody tr {
    /*cursor: pointer;*/
}

#imessage-inbox #imessage-inbox-spinner {
    display: none;
}

#imessage-inbox #imessage-inbox-spinner i {
    font-size: 18px;
}

#imessage-inbox .btn-group > .btn {
    border-radius: 0;
    width: 25px;
    float: none;
}

#imessage-inbox .btn-group > .btn:first-child:not(:last-child) {
/*    border-bottom: 0;*/
    margin:5px 0 5px 5px;
}

#imessage-inbox .sender-portrait {
    margin-right: 3px;
}

#imessage-inbox .inbox-clear-filter {
    position: absolute;
    top: 10px;
    right: 20px;
    cursor: pointer;
}

#imessage-inbox .user-information span {
	display: block;
}

@media (min-width: 992px) {
	#imessage-inbox .user-information span {
	   display: inline;
	}
	
	#imessage-inbox .user-portrait {
	   float: left;
	   margin-right: 3px;
	}
}




#message-stream ul.latest-messages li.latest-message.message-received.message-unread {
    border-color: #f0ad4e !important;
}


#message-stream ul.latest-messages li.latest-message .btn-group .btn {
    margin-right: 0;
}




#messages-controls .well.previous-messages {
    padding: 0;
    background-image: none;
    margin-top: 10px;
    text-align: center;
    cursor: pointer;
}

#messages-controls .well.previous-messages p {
    margin: 0;
    padding: 5px;
}

#messages-controls .well.previous-messages .previous-messages-loader {
    display: none;
}







#messages-dialog-partner span,
.messages-dialog-partner.is-fixed span {
	display: inline-block;
	overflow: hidden;
	text-overflow: ellipsis;
	white-space: nowrap;
	margin-left: 5px;
	vertical-align: top;
}


table#imessages-table { 
    margin-top:15px;
}

/* =========================================== */
/* 
Max width before this PARTICULAR table gets nasty
This query will take effect for any screen smaller than 760px
and also iPads specifically.
*/

/* wichtig: standard bootstrap überschreiben */

@media only screen and (max-width: 480px) {
/*(min-device-width: 768px) and (max-device-width: 996px)  */ 

	/* Force table to not be like tables anymore */

    table#imessages-table thead,
    table#imessages-table tbody,
    table#imessages-table tfoot,
    table#imessages-table th,
    table#imessages-table tr,
    table#imessages-table td { 
		display: block; 
	}
	
	/* Hide table headers (but not display: none;, for accessibility) */
	table#imessages-table thead tr { 
		position: absolute;
        border-bottom:1px solid #efefef;
		top: -9999px;
		left: -9999px;
	}
	table#imessages-table tr { 
        margin-bottom:2em;
	}
	
	table#imessages-table td { 
		/* Behave  like a "row" */
		position: relative;
                                    /* padding-left:80px; !important ; */
	}
	
	table#imessages-table td:before { 
		/* Now like a table header */
		position: absolute;
		/* Top/left values mimic padding */
		left: 0px;
		white-space: nowrap;
	}
	
	/*
	Label the data
	*/
                                    /*
                                    table#imessages-table td:before { content: attr(data-label); }
                                    */
}
