/*.portletInstantMessages  .portletHeader {
    background:transparent url("++resource++ityou.imessage.portlets.resources/portlet-imessage-icon.png") left center no-repeat;
    margin-left:10px;
    padding-left:25px;
}
*/
.portletInstantMessages dd a {
    padding-right:0px;
}

.portletInstantMessages dd a.portrait {
    padding:0;
}
.portletInstantMessages dd a.fullname {
}


.portletInstantMessages dd span.bar {
    display:block;
    height:6px;
    background:transparent url(++resource++ityou.whoisonline.resources/bar.gif) left center no-repeat;
}

/*
.portletWhoAmI dd a img {
    height: 120px !important;
    width: 80px !important;
}
*/

.portletInstantMessages dd div.clear {
    clear:left;
}

.portletInstantMessages .portletFooter {
    clear:both;
}

.portletWhoAmI  dd.portletItem,
.portletInstantMessages  dd.portletItem{
    padding:0 !important;
    border:none !important;
}

.imessage-sender-box {
    position:absolute;
           background: url(ie-transparent-bg-white.png) repeat;
           background: rgba(250, 250, 250, 0.95) !important;

    height:auto;
    min-height:20px;
    width:450px;
    border:1px solid #ccc;
           border:1px solid #CCC;
    box-shadow:0 0 8px rgba(0,0,0,0.2);
           box-shadow:0 0 12px rgba(100,100,100,0.6);
    border-radius:4px;
    padding:10px;
        display: none;
        font-size:11px;
        margin:30px 0 0 -10px;
    z-index:12;
}

#imessage-sender .arrow-top {
    background: transparent url("++resource++ityou.imessage.portlets.resources/arrow-gray-top.png") no-repeat 0px bottom ;
    position: absolute;
    height: 30px;
    width: 40px;
    margin:0px 0 0 0px;
    left: auto;
               display:none;
               z-index:1;
}
.img-clip {
    position:absolute;
    clip:rect(10px,40px,40px,10px);
    margin:-10px 0 0 -10px;
    width:40px;
    height:60px;

}
.img-portrait {
    position:absolute;
    clip:rect(0px,75px,100px,0px);
    margin:0px;
    width:75px;
        background-color:#eaeaea;
}
.portletInstantMessages .portrait {
    float:left;
    cursor:pointer;
       padding-right:0px;
}

/*
.info-profile {
    margin-left:80px;
    height:100px;
    color:#eaeaea;
}

.info-profile dd {

}
.info-profile dd {
    vertical-align: top;
     padding:4px;
}
*/



.sender-message-notify {
    background: transparent url("++resource++ityou.imessage.portlets.resources/bg-notify.png") no-repeat 0px bottom ;
        background:#ee0000;
        border-radius:6px;
    color: white;
    font-size: 10px;
    font-style: italic;
    font-weight: bold;
    margin: -10px 0 0 15px;
    padding: 1px 4px;
    position: absolute;
    z-index:1;
}

.imessage-sender-box .controls div {
    height:19px;
    width:19px;

}
.imessage-sender-box .controls .read {
    background: transparent url("++resource++ityou.imessage.portlets.resources/read-icon.png") no-repeat left center ;
    float:right;
       padding:4px;
       opacity:0.3;
}
.imessage-sender-box .controls .read:hover,
.imessage-sender-box .controls .read-ok {
    background: transparent url("++resource++ityou.imessage.portlets.resources/read-icon-active.png") no-repeat left center ;
    padding:4px;
    float:right;
       opacity:1;
}
.imessage-sender-box .controls .delete {
    background: transparent url("++resource++ityou.imessage.portlets.resources/delete-icon.png") no-repeat left center ;
    padding:4px;
    float:right;
       opacity:0.3;
}
.imessage-sender-box .controls .delete:hover,
.imessage-sender-box .controls .delete-ok  {
    background: transparent url("++resource++ityou.imessage.portlets.resources/delete-icon-active.png") no-repeat left center ;
    padding:4px;
    float:right;
       opacity:1;
}
.imessage-sender-box .controls .reply {
    background: transparent url("++resource++ityou.imessage.portlets.resources/reply-icon.png") no-repeat left center ;
    padding:4px;
    float:right;
}
.imessage-sender-box .controls .reply:hover {
    background: transparent url("++resource++ityou.imessage.portlets.resources/reply-icon-active.png") no-repeat left center ;
}

.imessage-sender-box .message {
    background-color:#eaeaea;
    border:1px solid #CCC;
    border-radius:5px;
    padding:10px;
    width:88%;
           /*white-space:pre;*/
}
.imessage-sender-box .message:hover {
    background:#f6f6f6;
}
.imessage-sender-box .message.read-ok {
       border:1px solid #789F09;
           background-color:#E9FDD7;
}
.imessage-sender-box .message.delete-ok {
       border:1px solid #cc0000;
           background:#ffefef;
}

.imessage-sender-box dd {
    padding-top:1em;
}


#debug-imessage {
    background-color: #f60;
    border-radius: 0.5em 0.5em 0 0;
    bottom: 0;
    color: white;
    font-size: 10px;
    min-height: 14px;
    min-width: 5em;
    padding: 2px 6px;
    position: fixed;
    right: 120px;
    z-index:10;
}


.portletInstantMessages .small-personal-portrait {
 /* 48px */
}

